/* David Leonard, 2002. Public domain. */

/* Simple UCS-2LE conversion library */

#include <sys/types.h>
#include <machine/endian.h>
#include "ustring.h"

#define CTOU(c)		htole16((char)(c))
#define UTOC(u)		(letoh16((uchar)(u)) & 0xff)

/* Compute UCS-2LE string length in UCS-2LE units */
int
ustrlen(s)
	const uchar *s;
{
	const uchar *p;
	for (p = s; *p != 0; p++)
		;
	return p - s;
}

/* Convert UCS-2LE string to host string, returning bytes used */
size_t
ctou(us, ulen, s)
	uchar *us;
	size_t ulen;
	const char *s;
{
	const char *p = s;
	uchar *up = us;

	for (p = s, up = us; ulen-- && *p; p++, up++)
		*up = CTOU(*p);
	if (ulen)
		*up++ = 0;
	return (up - us) * sizeof (uchar);
}

/* Convert host string to UCS-2LE string, returning bytes used */
size_t
utoc(s, len, us)
	char *s;
	size_t len;
	const uchar *us;
{
	const uchar *up = us;
	char *p = s;

	for (p = s, up = us; len-- && *up; p++, up++)
		*p = UTOC(*up);
	if (len)
		*p++ = 0;
	return (p - s) * sizeof (char);
}
